==> ros-humble-rmw-zenoh-cpp_0.1.0.orig.tar.gz: ros-humble-rmw-zenoh-cpp-0.1.0/src/detail/attachment_helpers.cpp <==
// Copyright 2024 Open Source Robotics Foundation, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include <array>
#include <cstdlib>
#include <cstring>
#include <stdexcept>
#include <string>
#include <utility>

#include <zenoh.hxx>

#include "rmw/types.h"

#include "attachment_helpers.hpp"
#include "liveliness_utils.hpp"

namespace rmw_zenoh_cpp
{

AttachmentData::AttachmentData(
  const int64_t sequence_number,
  const int64_t source_timestamp,
  const std::array<uint8_t, 16> source_gid)
: sequence_number_(sequence_number),
  source_timestamp_(source_timestamp),
  source_gid_(source_gid),
  gid_hash_(hash_gid(source_gid))
{
}

AttachmentData::AttachmentData(AttachmentData && data)
{
  gid_hash_ = std::move(data.gid_hash_);
  sequence_number_ = std::move(data.sequence_number_);
  source_timestamp_ = std::move(data.source_timestamp_);
  source_gid_ = data.source_gid_;
}

///=============================================================================
int64_t AttachmentData::sequence_number() const
{
  return sequence_number_;
}

///=============================================================================
int64_t AttachmentData::source_timestamp() const
{
  return source_timestamp_;
}

///=============================================================================
std::array<uint8_t, 16> AttachmentData::copy_gid() const
{
  return source_gid_;
}

///=============================================================================
size_t AttachmentData::gid_hash() const
{
  return gid_hash_;
}

zenoh::Bytes AttachmentData::serialize_to_zbytes()
{
  auto serializer = zenoh::ext::Serializer();
  serializer.serialize(std::string("sequence_number"));
  serializer.serialize(this->sequence_number_);
  serializer.serialize(std::string("source_timestamp"));
  serializer.serialize(this->source_timestamp_);
  serializer.serialize(std::string("source_gid"));
  serializer.serialize(this->source_gid_);
  return std::move(serializer).finish();
}

AttachmentData::AttachmentData(const zenoh::Bytes & bytes)
{
  zenoh::ext::Deserializer deserializer(bytes);
  const auto sequence_number_str = deserializer.deserialize<std::string>();
  if (sequence_number_str != "sequence_number") {
    throw std::runtime_error("sequence_number is not found in the attachment.");
  }
  this->sequence_number_ = deserializer.deserialize<int64_t>();

  const auto source_timestamp_str = deserializer.deserialize<std::string>();
  if (source_timestamp_str != "source_timestamp") {
    throw std::runtime_error("source_timestamp is not found in the attachment.");
  }
  this->source_timestamp_ = deserializer.deserialize<int64_t>();

  const auto source_gid_str = deserializer.deserialize<std::string>();
  if (source_gid_str != "source_gid") {
    throw std::runtime_error("source_gid is not found in the attachment.");
  }
  this->source_gid_ = deserializer.deserialize<std::array<uint8_t, 16>>();
  gid_hash_ = hash_gid(this->source_gid_);
}
}  // namespace rmw_zenoh_cpp

==> ros-humble-rmw-zenoh-cpp_0.1.1.orig.tar.gz: ros-humble-rmw-zenoh-cpp-0.1.1/src/detail/attachment_helpers.cpp <==
// Copyright 2024 Open Source Robotics Foundation, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include <array>
#include <cstdlib>
#include <cstring>
#include <stdexcept>
#include <string>
#include <utility>

#include <zenoh.hxx>

#include "rmw/types.h"

#include "attachment_helpers.hpp"
#include "liveliness_utils.hpp"

namespace rmw_zenoh_cpp
{

AttachmentData::AttachmentData(
  const int64_t sequence_number,
  const int64_t source_timestamp,
  const std::array<uint8_t, 16> source_gid)
: sequence_number_(sequence_number),
  source_timestamp_(source_timestamp),
  source_gid_(source_gid)
{
}

AttachmentData::AttachmentData(AttachmentData && data)
{
  sequence_number_ = std::move(data.sequence_number_);
  source_timestamp_ = std::move(data.source_timestamp_);
  source_gid_ = data.source_gid_;
}

///=============================================================================
int64_t AttachmentData::sequence_number() const
{
  return sequence_number_;
}

///=============================================================================
int64_t AttachmentData::source_timestamp() const
{
  return source_timestamp_;
}

///=============================================================================
std::array<uint8_t, 16> AttachmentData::copy_gid() const
{
  return source_gid_;
}

zenoh::Bytes AttachmentData::serialize_to_zbytes()
{
  auto serializer = zenoh::ext::Serializer();
  serializer.serialize(std::string("sequence_number"));
  serializer.serialize(this->sequence_number_);
  serializer.serialize(std::string("source_timestamp"));
  serializer.serialize(this->source_timestamp_);
  serializer.serialize(std::string("source_gid"));
  serializer.serialize(this->source_gid_);
  return std::move(serializer).finish();
}

AttachmentData::AttachmentData(const zenoh::Bytes & bytes)
{
  zenoh::ext::Deserializer deserializer(bytes);
  const auto sequence_number_str = deserializer.deserialize<std::string>();
  if (sequence_number_str != "sequence_number") {
    throw std::runtime_error("sequence_number is not found in the attachment.");
  }
  this->sequence_number_ = deserializer.deserialize<int64_t>();

  const auto source_timestamp_str = deserializer.deserialize<std::string>();
  if (source_timestamp_str != "source_timestamp") {
    throw std::runtime_error("source_timestamp is not found in the attachment.");
  }
  this->source_timestamp_ = deserializer.deserialize<int64_t>();

  const auto source_gid_str = deserializer.deserialize<std::string>();
  if (source_gid_str != "source_gid") {
    throw std::runtime_error("source_gid is not found in the attachment.");
  }
  this->source_gid_ = deserializer.deserialize<std::array<uint8_t, 16>>();
}
}  // namespace rmw_zenoh_cpp
